@@ -14,8 +14,7 @@ HMacBuf::HMacBuf(std::string const &key, char const *type, size_t bufsize)
             if (type == 0)
                 type = "** unspecified hmac-digest type **";
     
-            throw Errno(1, "HMacBuf `") << insertable << type << 
-                                            "' not available" << throwable;
+            throw Errno(1, "HMacBuf `") << type << "' not available";
         }
         d_pimpl->buffer = new char[bufsize];
         open();
