@@ -4,5 +4,5 @@ string Milter::s_name;
 Milter *Milter::s_mp;
 bool Milter::s_callClose;
 
-map<SMFICTX *, Milter *> Milter::s_map;
+unordered_map<SMFICTX *, Milter *> Milter::s_map;
 
