@@ -4,14 +4,15 @@
 
 void Process::forking()
 {
+    if (d_mode == IOMode::DIRECT)
+        childProcess();
+
     fork();
 
     // this is the parent, following parentRedirections()
     
     d_child.pid = pid();
 
-//std::cerr << "FORKED CHILD " << pid() << endl;
-
     if (d_timeLimit == 0)         // no wait, set monitor.pid to 0: no 
     {                               // time monitoring
         d_monitor.pid = 0;
@@ -24,28 +25,18 @@ void Process::forking()
     {
         d_monitor.pid = 0;
         stop();
-        throw Errno("Process ") << insertable << d_command << 
-                    ": can't start the timeout monitor" << throwable;
+        throw Errno("Process ") << d_command << 
+                                        ": can't start the timeout monitor";
     }
     else if (d_monitor.pid == 0)    // actual monitoring process
     {
                                     // close open pipes inherited from the
                                     // parent process
-        if (d_mode & CIN)           
-            ::close(d_child_inp->writeOnly());
-        if (d_mode & (COUT | MERGE_COUT_CERR))
-            ::close(d_child_outp->readOnly());
-        if (d_mode & CERR)
-            ::close(d_child_errp->readOnly());
-
-        sleep(d_timeLimit);
+        closeWriteFd(d_oChildInPipe);
+        closeReadFd(d_iChildOutPipe);
+        closeReadFd(d_iChildErrPipe);
 
+        sleep(d_timeLimit);         // end the child after 'timeLimit'
         exit(0);
     }
 }
-
-
-
-
-
-
